# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.source_map_upload_config import SourceMapUploadConfig

class TestSourceMapUploadConfig(unittest.TestCase):
    """SourceMapUploadConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SourceMapUploadConfig:
        """Test SourceMapUploadConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SourceMapUploadConfig`
        """
        model = SourceMapUploadConfig()
        if include_optional:
            return SourceMapUploadConfig(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                description = '',
                id = '',
                metadata = [
                    instana_client.models.source_map_file_meta.SourceMapFileMeta(
                        blobs = [
                            instana_client.models.source_map_file_blob.SourceMapFileBlob(
                                blob_index = 56, 
                                size = 56, 
                                size_on_disk = 56, )
                            ], 
                        format = '', 
                        meta = '', 
                        size = 56, 
                        size_on_disk = 56, 
                        type = 'JS_MAP', 
                        url = '', )
                    ],
                modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return SourceMapUploadConfig(
                id = '',
                metadata = [
                    instana_client.models.source_map_file_meta.SourceMapFileMeta(
                        blobs = [
                            instana_client.models.source_map_file_blob.SourceMapFileBlob(
                                blob_index = 56, 
                                size = 56, 
                                size_on_disk = 56, )
                            ], 
                        format = '', 
                        meta = '', 
                        size = 56, 
                        size_on_disk = 56, 
                        type = 'JS_MAP', 
                        url = '', )
                    ],
        )
        """

    def testSourceMapUploadConfig(self):
        """Test SourceMapUploadConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from instana_client.models.abstract_rule import AbstractRule
from instana_client.models.metric_pattern import MetricPattern
from typing import Optional, Set
from typing_extensions import Self

class ThresholdRule(AbstractRule):
    """
    ThresholdRule
    """ # noqa: E501
    aggregation: Optional[StrictStr] = None
    condition_operator: StrictStr = Field(alias="conditionOperator")
    condition_value: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="conditionValue")
    metric_name: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=512)]] = Field(default=None, alias="metricName")
    metric_pattern: Optional[MetricPattern] = Field(default=None, alias="metricPattern")
    rollup: Optional[StrictInt] = None
    window: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["ruleType", "severity", "aggregation", "conditionOperator", "conditionValue", "metricName", "metricPattern", "rollup", "window"]

    @field_validator('aggregation')
    def aggregation_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['sum', 'avg', 'min', 'max', 'absolute_diff', 'relative_diff']):
            raise ValueError("must be one of enum values ('sum', 'avg', 'min', 'max', 'absolute_diff', 'relative_diff')")
        return value

    @field_validator('condition_operator')
    def condition_operator_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['>', '>=', '<', '<=', '=', '!=']):
            raise ValueError("must be one of enum values ('>', '>=', '<', '<=', '=', '!=')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ThresholdRule from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of metric_pattern
        if self.metric_pattern:
            _dict['metricPattern'] = self.metric_pattern.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ThresholdRule from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "ruleType": obj.get("ruleType"),
            "severity": obj.get("severity"),
            "aggregation": obj.get("aggregation"),
            "conditionOperator": obj.get("conditionOperator"),
            "conditionValue": obj.get("conditionValue"),
            "metricName": obj.get("metricName"),
            "metricPattern": MetricPattern.from_dict(obj["metricPattern"]) if obj.get("metricPattern") is not None else None,
            "rollup": obj.get("rollup"),
            "window": obj.get("window")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.304.1059
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from instana_client.models.service_level_indicator import ServiceLevelIndicator
from instana_client.models.slo_entity import SloEntity
from instana_client.models.time_window import TimeWindow
from typing import Optional, Set
from typing_extensions import Self

class ServiceLevelObjectiveConfiguration(BaseModel):
    """
    ServiceLevelObjectiveConfiguration
    """ # noqa: E501
    created_date: Optional[datetime] = Field(default=None, description="Created date of Service Levels Objective Configuration", alias="createdDate")
    entity: SloEntity
    id: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=64)]] = Field(default=None, description="Service Levels Objective Configuration ID")
    indicator: ServiceLevelIndicator
    last_updated: Optional[datetime] = Field(default=None, description="Last updated date of Service Levels Objective Configuration", alias="lastUpdated")
    name: StrictStr = Field(description="Name of the Service Levels Objective Configuration")
    tags: List[StrictStr] = Field(description="List of tags associated with Service Levels Objective Configuration")
    target: Union[Annotated[float, Field(le=0.9999, strict=True, gt=0.0)], Annotated[int, Field(le=0, strict=True, gt=0)]] = Field(description="Service Levels Objective Configuration Target")
    time_window: TimeWindow = Field(alias="timeWindow")
    __properties: ClassVar[List[str]] = ["createdDate", "entity", "id", "indicator", "lastUpdated", "name", "tags", "target", "timeWindow"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ServiceLevelObjectiveConfiguration from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of entity
        if self.entity:
            _dict['entity'] = self.entity.to_dict()
        # override the default output from pydantic by calling `to_dict()` of indicator
        if self.indicator:
            _dict['indicator'] = self.indicator.to_dict()
        # override the default output from pydantic by calling `to_dict()` of time_window
        if self.time_window:
            _dict['timeWindow'] = self.time_window.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ServiceLevelObjectiveConfiguration from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "createdDate": obj.get("createdDate"),
            "entity": SloEntity.from_dict(obj["entity"]) if obj.get("entity") is not None else None,
            "id": obj.get("id"),
            "indicator": ServiceLevelIndicator.from_dict(obj["indicator"]) if obj.get("indicator") is not None else None,
            "lastUpdated": obj.get("lastUpdated"),
            "name": obj.get("name"),
            "tags": obj.get("tags"),
            "target": obj.get("target"),
            "timeWindow": TimeWindow.from_dict(obj["timeWindow"]) if obj.get("timeWindow") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.type_configuration import TypeConfiguration

class TestTypeConfiguration(unittest.TestCase):
    """TypeConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TypeConfiguration:
        """Test TypeConfiguration
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TypeConfiguration`
        """
        model = TypeConfiguration()
        if include_optional:
            return TypeConfiguration(
                condition = instana_client.models.condition.Condition(
                    query = '', ),
                name = 'automatic',
                runnable = instana_client.models.policy_runnable.PolicyRunnable(
                    id = '', 
                    run_configuration = instana_client.models.run_configuration.RunConfiguration(
                        actions = [
                            instana_client.models.action_configuration.ActionConfiguration(
                                action = instana_client.models.action.Action(
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    description = '', 
                                    fields = [
                                        instana_client.models.field.Field(
                                            description = '', 
                                            encoding = '', 
                                            name = '', 
                                            secured = True, 
                                            value = '', )
                                        ], 
                                    id = '0', 
                                    input_parameters = [
                                        instana_client.models.parameter.Parameter(
                                            description = '', 
                                            hidden = True, 
                                            label = '', 
                                            name = '', 
                                            required = True, 
                                            secured = True, 
                                            type = '', 
                                            value = '', )
                                        ], 
                                    metadata = instana_client.models.meta_data.MetaData(
                                        ai = [
                                            {
                                                'key' : None
                                                }
                                            ], 
                                        ai_originated = True, 
                                        built_in = True, 
                                        read_only = True, 
                                        sensor_imported = True, ), 
                                    modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    name = '0', 
                                    tags = [
                                        ''
                                        ], 
                                    type = 'SCRIPT', ), 
                                agent_id = '', 
                                input_parameter_values = [
                                    instana_client.models.parameter_value.ParameterValue(
                                        name = '', 
                                        value = '', )
                                    ], )
                            ], ), 
                    type = 'action', )
            )
        else:
            return TypeConfiguration(
                name = 'automatic',
                runnable = instana_client.models.policy_runnable.PolicyRunnable(
                    id = '', 
                    run_configuration = instana_client.models.run_configuration.RunConfiguration(
                        actions = [
                            instana_client.models.action_configuration.ActionConfiguration(
                                action = instana_client.models.action.Action(
                                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    description = '', 
                                    fields = [
                                        instana_client.models.field.Field(
                                            description = '', 
                                            encoding = '', 
                                            name = '', 
                                            secured = True, 
                                            value = '', )
                                        ], 
                                    id = '0', 
                                    input_parameters = [
                                        instana_client.models.parameter.Parameter(
                                            description = '', 
                                            hidden = True, 
                                            label = '', 
                                            name = '', 
                                            required = True, 
                                            secured = True, 
                                            type = '', 
                                            value = '', )
                                        ], 
                                    metadata = instana_client.models.meta_data.MetaData(
                                        ai = [
                                            {
                                                'key' : None
                                                }
                                            ], 
                                        ai_originated = True, 
                                        built_in = True, 
                                        read_only = True, 
                                        sensor_imported = True, ), 
                                    modified_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                    name = '0', 
                                    tags = [
                                        ''
                                        ], 
                                    type = 'SCRIPT', ), 
                                agent_id = '', 
                                input_parameter_values = [
                                    instana_client.models.parameter_value.ParameterValue(
                                        name = '', 
                                        value = '', )
                                    ], )
                            ], ), 
                    type = 'action', ),
        )
        """

    def testTypeConfiguration(self):
        """Test TypeConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.users_result import UsersResult

class TestUsersResult(unittest.TestCase):
    """UsersResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UsersResult:
        """Test UsersResult
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UsersResult`
        """
        model = UsersResult()
        if include_optional:
            return UsersResult(
                invitations = [
                    instana_client.models.invitation_result.InvitationResult(
                        invitation_status = 'SUCCESS', 
                        user_email = '', )
                    ],
                users = [
                    instana_client.models.user_result.UserResult(
                        email = '', 
                        full_name = '', 
                        group_count = 56, 
                        id = '', 
                        last_logged_in = 56, 
                        tfa_enabled = True, )
                    ]
            )
        else:
            return UsersResult(
        )
        """

    def testUsersResult(self):
        """Test UsersResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from instana_client.models.action_instance_metadata_entry import ActionInstanceMetadataEntry
from instana_client.models.action_instance_parameter import ActionInstanceParameter
from typing import Optional, Set
from typing_extensions import Self

class ActionInstance(BaseModel):
    """
    ActionInstance
    """ # noqa: E501
    action_description: Optional[StrictStr] = Field(default=None, description="Action description of the action to run.", alias="actionDescription")
    action_id: StrictStr = Field(description="Action identifier of the action to run.", alias="actionId")
    action_instance_id: Optional[StrictStr] = Field(default=None, description="Action run identifier.", alias="actionInstanceId")
    action_name: StrictStr = Field(description="Action name of the action to run.", alias="actionName")
    action_snapshot: Optional[StrictStr] = Field(default=None, description="Snapshot of the action definition.", alias="actionSnapshot")
    actor_id: Optional[StrictStr] = Field(default=None, description="User identifier, API token or the policy identifier that started the action run.", alias="actorId")
    actor_name: Optional[StrictStr] = Field(default=None, description="Name of the user, API token or the policy that started the action run.", alias="actorName")
    actor_type: Optional[StrictStr] = Field(default=None, description="Type of Actor. Valid values are listed in the enum definition.", alias="actorType")
    created_date: Optional[StrictInt] = Field(default=None, description="Action run created timestamp. The timestamp at which the action run got submitted.", alias="createdDate")
    end_date: Optional[StrictInt] = Field(default=None, description="Action run end timestamp. The timestamp at which the action run ended on the agent host.", alias="endDate")
    error_message: Optional[StrictStr] = Field(default=None, description="Error message, if any, of action run on the agent host.", alias="errorMessage")
    event_entity_type: Optional[StrictStr] = Field(default=None, description="Event entity type set in the event that triggered this action run.", alias="eventEntityType")
    event_id: Optional[StrictStr] = Field(default=None, description="Event identifier of the event that triggered this action run.", alias="eventId")
    event_specification_id: Optional[StrictStr] = Field(default=None, description="Event specification identifier of the event that triggered this action run.", alias="eventSpecificationId")
    external_source_type: Optional[StrictStr] = Field(default=None, description="If the action type is external this field contains the name of the external source.", alias="externalSourceType")
    host_snapshot_id: Optional[StrictStr] = Field(default=None, description="Host snapshot identifier of the agent on which the action ran.", alias="hostSnapshotId")
    input_parameters: Optional[List[ActionInstanceParameter]] = Field(default=None, description="List of input parameters to this action run.", alias="inputParameters")
    metadata: Optional[List[ActionInstanceMetadataEntry]] = Field(default=None, description="List of metadata parameters set to this action run by sensors.")
    output: Optional[StrictStr] = Field(default=None, description="Action run output.")
    policy_id: Optional[StrictStr] = Field(default=None, description="Identifier of the policy that triggered this action run.", alias="policyId")
    problem_text: Optional[StrictStr] = Field(default=None, description="Event problem text of the event that triggered this action run.", alias="problemText")
    return_code: Optional[StrictInt] = Field(default=None, description="Return code of action run on the agent host.", alias="returnCode")
    start_date: Optional[StrictInt] = Field(default=None, description="Action run start timestamp. The timestamp at which the action run started on the agent host.", alias="startDate")
    status: Optional[StrictStr] = Field(default=None, description="Action run status. Valid values are listed in the enum definition.")
    target_snapshot_id: Optional[StrictStr] = Field(default=None, description="Action target entity identifier set in the event that triggered this action run. This is the identifier of the entity on which an incident or issue was raised.", alias="targetSnapshotId")
    type: StrictStr = Field(description="Action type. Valid values are listed in the enum definition.")
    __properties: ClassVar[List[str]] = ["actionDescription", "actionId", "actionInstanceId", "actionName", "actionSnapshot", "actorId", "actorName", "actorType", "createdDate", "endDate", "errorMessage", "eventEntityType", "eventId", "eventSpecificationId", "externalSourceType", "hostSnapshotId", "inputParameters", "metadata", "output", "policyId", "problemText", "returnCode", "startDate", "status", "targetSnapshotId", "type"]

    @field_validator('actor_type')
    def actor_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['ACTOR_UNKNOWN', 'USER', 'APITOKEN', 'POLICY']):
            raise ValueError("must be one of enum values ('ACTOR_UNKNOWN', 'USER', 'APITOKEN', 'POLICY')")
        return value

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['STATUS_UNKNOWN', 'SUBMITTED', 'IN_PROGRESS', 'SUCCESS', 'FAILED', 'READY', 'TIMEOUT']):
            raise ValueError("must be one of enum values ('STATUS_UNKNOWN', 'SUBMITTED', 'IN_PROGRESS', 'SUCCESS', 'FAILED', 'READY', 'TIMEOUT')")
        return value

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['SCRIPT', 'HTTP', 'ANSIBLE', 'EXTERNAL', 'GITHUB', 'GITLAB', 'JIRA', 'MANUAL', 'DOC_LINK']):
            raise ValueError("must be one of enum values ('SCRIPT', 'HTTP', 'ANSIBLE', 'EXTERNAL', 'GITHUB', 'GITLAB', 'JIRA', 'MANUAL', 'DOC_LINK')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ActionInstance from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "action_instance_id",
            "action_snapshot",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in input_parameters (list)
        _items = []
        if self.input_parameters:
            for _item_input_parameters in self.input_parameters:
                if _item_input_parameters:
                    _items.append(_item_input_parameters.to_dict())
            _dict['inputParameters'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in metadata (list)
        _items = []
        if self.metadata:
            for _item_metadata in self.metadata:
                if _item_metadata:
                    _items.append(_item_metadata.to_dict())
            _dict['metadata'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ActionInstance from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "actionDescription": obj.get("actionDescription"),
            "actionId": obj.get("actionId"),
            "actionInstanceId": obj.get("actionInstanceId"),
            "actionName": obj.get("actionName"),
            "actionSnapshot": obj.get("actionSnapshot"),
            "actorId": obj.get("actorId"),
            "actorName": obj.get("actorName"),
            "actorType": obj.get("actorType"),
            "createdDate": obj.get("createdDate"),
            "endDate": obj.get("endDate"),
            "errorMessage": obj.get("errorMessage"),
            "eventEntityType": obj.get("eventEntityType"),
            "eventId": obj.get("eventId"),
            "eventSpecificationId": obj.get("eventSpecificationId"),
            "externalSourceType": obj.get("externalSourceType"),
            "hostSnapshotId": obj.get("hostSnapshotId"),
            "inputParameters": [ActionInstanceParameter.from_dict(_item) for _item in obj["inputParameters"]] if obj.get("inputParameters") is not None else None,
            "metadata": [ActionInstanceMetadataEntry.from_dict(_item) for _item in obj["metadata"]] if obj.get("metadata") is not None else None,
            "output": obj.get("output"),
            "policyId": obj.get("policyId"),
            "problemText": obj.get("problemText"),
            "returnCode": obj.get("returnCode"),
            "startDate": obj.get("startDate"),
            "status": obj.get("status"),
            "targetSnapshotId": obj.get("targetSnapshotId"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class SyntheticMetricTagGroup(BaseModel):
    """
     Grouping of data under `groupbyTag`, where `groupbyTagEntity` and `groupbyTagSecondLevelKey` are aspects of `groupbyTag`.
    """ # noqa: E501
    direction: StrictStr
    groupby_tag: Annotated[str, Field(min_length=0, strict=True, max_length=256)] = Field(description="The name of the group tag (e.g. `agent.tag` or `docker.label`).", alias="groupbyTag")
    groupby_tag_entity: StrictStr = Field(description="The entity by which the data should be grouped. This field supports three possible values: `NOT_APPLICABLE`, `DESTINATION`, and `SOURCE`. `SOURCE`: the tag filter should apply to the source entity. `DESTINATION`: the tag filter should apply to the destination entity. `NOT_APPLICABLE`: some tags are independent of source or destination, such as tags on the call itself, log tags or trace tags (only destination makes sense because the source is unknown for the root call). ", alias="groupbyTagEntity")
    groupby_tag_second_level_key: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=256)]] = Field(default=None, description="If present, it's the 2nd level key part (e.g. `customKey` on `docker.label.customKey`)", alias="groupbyTagSecondLevelKey")
    include_others: Optional[StrictBool] = Field(default=None, alias="includeOthers")
    max_results: Optional[Annotated[int, Field(le=50, strict=True, ge=1)]] = Field(default=None, alias="maxResults")
    __properties: ClassVar[List[str]] = ["direction", "groupbyTag", "groupbyTagEntity", "groupbyTagSecondLevelKey", "includeOthers", "maxResults"]

    @field_validator('direction')
    def direction_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['ASC', 'DESC']):
            raise ValueError("must be one of enum values ('ASC', 'DESC')")
        return value

    @field_validator('groupby_tag_entity')
    def groupby_tag_entity_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['NOT_APPLICABLE', 'DESTINATION', 'SOURCE']):
            raise ValueError("must be one of enum values ('NOT_APPLICABLE', 'DESTINATION', 'SOURCE')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SyntheticMetricTagGroup from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SyntheticMetricTagGroup from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "direction": obj.get("direction"),
            "groupbyTag": obj.get("groupbyTag"),
            "groupbyTagEntity": obj.get("groupbyTagEntity"),
            "groupbyTagSecondLevelKey": obj.get("groupbyTagSecondLevelKey"),
            "includeOthers": obj.get("includeOthers"),
            "maxResults": obj.get("maxResults")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from instana_client.models.call_relation import CallRelation
from typing import Optional, Set
from typing_extensions import Self

class GetTraceDownloadResultItem(BaseModel):
    """
    Represents an array of call group item containing several attributes that describe its properties. The item includes fields such as cursor, metrics, name, and timestamp, which provide detailed information about the item. 
    """ # noqa: E501
    call_count: Optional[StrictInt] = Field(default=None, description="Number of calls in a trace.", alias="callCount")
    cursor: Optional[Dict[str, Any]] = Field(default=None, description="Cursor to use between successive queries")
    destination: Optional[CallRelation] = None
    duration: Optional[StrictInt] = Field(default=None, description="The total time taken for the entire operation of a call, from the moment the request was initiated to when the response was received. The time measured is in milliseconds. This is also known as latency of a call.")
    error_count: Optional[StrictInt] = Field(default=None, description="Represents whether the call is erroneous or not. 0 is not erroneous and 1 is erroneous.", alias="errorCount")
    foreign_parent_id: Optional[StrictStr] = Field(default=None, alias="foreignParentId")
    id: Optional[StrictStr] = Field(default=None, description="The call ID. A unique identifier for an individual call. For example: `1bcad5c82338deaf`.")
    min_self_time: Optional[StrictInt] = Field(default=None, description="The smallest self time in the batch. May be null to indicate that `minSelfTime` is unknown when this node has only an exit span and no children. The time measured is in milliseconds.", alias="minSelfTime")
    name: Optional[StrictStr] = Field(default=None, description="Name of the call. For example: `GET /articles/:id`.")
    network_time: Optional[StrictInt] = Field(default=None, description="exit span duration - entry span duration", alias="networkTime")
    parent_id: Optional[StrictStr] = Field(default=None, description="The parent call id, referring to another call in the same trace which triggered the processing associated with this call.", alias="parentId")
    timestamp: Optional[StrictInt] = Field(default=None, description="The timestamp when the call or request was initiated. For example, Unix epoch time in milliseconds `1735532879870` is `Monday, 30 December 2024 04:27:59.870 GMT`")
    __properties: ClassVar[List[str]] = ["callCount", "cursor", "destination", "duration", "errorCount", "foreignParentId", "id", "minSelfTime", "name", "networkTime", "parentId", "timestamp"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GetTraceDownloadResultItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of destination
        if self.destination:
            _dict['destination'] = self.destination.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GetTraceDownloadResultItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "callCount": obj.get("callCount"),
            "cursor": obj.get("cursor"),
            "destination": CallRelation.from_dict(obj["destination"]) if obj.get("destination") is not None else None,
            "duration": obj.get("duration"),
            "errorCount": obj.get("errorCount"),
            "foreignParentId": obj.get("foreignParentId"),
            "id": obj.get("id"),
            "minSelfTime": obj.get("minSelfTime"),
            "name": obj.get("name"),
            "networkTime": obj.get("networkTime"),
            "parentId": obj.get("parentId"),
            "timestamp": obj.get("timestamp")
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.3"

# import apis into sdk package
from instana_client.api.ai_management_api import AIManagementApi
from instana_client.api.api_token_api import APITokenApi
from instana_client.api.action_catalog_api import ActionCatalogApi
from instana_client.api.action_history_api import ActionHistoryApi
from instana_client.api.apdex_report_api import ApdexReportApi
from instana_client.api.apdex_settings_api import ApdexSettingsApi
from instana_client.api.application_alert_configuration_api import ApplicationAlertConfigurationApi
from instana_client.api.application_analyze_api import ApplicationAnalyzeApi
from instana_client.api.application_catalog_api import ApplicationCatalogApi
from instana_client.api.application_metrics_api import ApplicationMetricsApi
from instana_client.api.application_resources_api import ApplicationResourcesApi
from instana_client.api.application_settings_api import ApplicationSettingsApi
from instana_client.api.application_topology_api import ApplicationTopologyApi
from instana_client.api.audit_log_api import AuditLogApi
from instana_client.api.authentication_api import AuthenticationApi
from instana_client.api.business_monitoring_api import BusinessMonitoringApi
from instana_client.api.custom_dashboards_api import CustomDashboardsApi
from instana_client.api.custom_entities_api import CustomEntitiesApi
from instana_client.api.end_user_monitoring_api import EndUserMonitoringApi
from instana_client.api.event_settings_api import EventSettingsApi
from instana_client.api.events_api import EventsApi
from instana_client.api.global_application_alert_configuration_api import GlobalApplicationAlertConfigurationApi
from instana_client.api.groups_api import GroupsApi
from instana_client.api.health_api import HealthApi
from instana_client.api.host_agent_api import HostAgentApi
from instana_client.api.infrastructure_alert_configuration_api import InfrastructureAlertConfigurationApi
from instana_client.api.infrastructure_analyze_api import InfrastructureAnalyzeApi
from instana_client.api.infrastructure_catalog_api import InfrastructureCatalogApi
from instana_client.api.infrastructure_metrics_api import InfrastructureMetricsApi
from instana_client.api.infrastructure_resources_api import InfrastructureResourcesApi
from instana_client.api.infrastructure_topology_api import InfrastructureTopologyApi
from instana_client.api.log_alert_configuration_api import LogAlertConfigurationApi
from instana_client.api.logging_analyze_api import LoggingAnalyzeApi
from instana_client.api.maintenance_configuration_api import MaintenanceConfigurationApi
from instana_client.api.mobile_app_analyze_api import MobileAppAnalyzeApi
from instana_client.api.mobile_app_catalog_api import MobileAppCatalogApi
from instana_client.api.mobile_app_configuration_api import MobileAppConfigurationApi
from instana_client.api.mobile_app_metrics_api import MobileAppMetricsApi
from instana_client.api.policies_api import PoliciesApi
from instana_client.api.releases_api import ReleasesApi
from instana_client.api.roles_api import RolesApi
from instana_client.api.sli_report_api import SLIReportApi
from instana_client.api.sli_settings_api import SLISettingsApi
from instana_client.api.slo_correction_configurations_api import SLOCorrectionConfigurationsApi
from instana_client.api.slo_correction_windows_api import SLOCorrectionWindowsApi
from instana_client.api.service_levels_alert_configuration_api import ServiceLevelsAlertConfigurationApi
from instana_client.api.service_levels_objective_slo_configurations_api import ServiceLevelsObjectiveSLOConfigurationsApi
from instana_client.api.service_levels_objective_slo_report_api import ServiceLevelsObjectiveSLOReportApi
from instana_client.api.session_settings_api import SessionSettingsApi
from instana_client.api.synthetic_alert_configuration_api import SyntheticAlertConfigurationApi
from instana_client.api.synthetic_calls_api import SyntheticCallsApi
from instana_client.api.synthetic_catalog_api import SyntheticCatalogApi
from instana_client.api.synthetic_metrics_api import SyntheticMetricsApi
from instana_client.api.synthetic_settings_api import SyntheticSettingsApi
from instana_client.api.synthetic_test_playback_results_api import SyntheticTestPlaybackResultsApi
from instana_client.api.teams_api import TeamsApi
from instana_client.api.usage_api import UsageApi
from instana_client.api.user_api import UserApi
from instana_client.api.website_analyze_api import WebsiteAnalyzeApi
from instana_client.api.website_catalog_api import WebsiteCatalogApi
from instana_client.api.website_configuration_api import WebsiteConfigurationApi
from instana_client.api.website_metrics_api import WebsiteMetricsApi

# import ApiClient
from instana_client.api_response import ApiResponse
from instana_client.api_client import ApiClient
from instana_client.configuration import Configuration
from instana_client.exceptions import OpenApiException
from instana_client.exceptions import ApiTypeError
from instana_client.exceptions import ApiValueError
from instana_client.exceptions import ApiKeyError
from instana_client.exceptions import ApiAttributeError
from instana_client.exceptions import ApiException

# import models into sdk package
from instana_client.models.abstract_integration import AbstractIntegration
from instana_client.models.abstract_rule import AbstractRule
from instana_client.models.access_log_entry import AccessLogEntry
from instana_client.models.access_log_response import AccessLogResponse
from instana_client.models.access_rule import AccessRule
from instana_client.models.action import Action
from instana_client.models.action_configuration import ActionConfiguration
from instana_client.models.action_instance import ActionInstance
from instana_client.models.action_instance_metadata_entry import ActionInstanceMetadataEntry
from instana_client.models.action_instance_parameter import ActionInstanceParameter
from instana_client.models.action_instance_request import ActionInstanceRequest
from instana_client.models.action_instance_request_parameters import ActionInstanceRequestParameters
from instana_client.models.action_match import ActionMatch
from instana_client.models.action_search_space import ActionSearchSpace
from instana_client.models.adaptive_baseline import AdaptiveBaseline
from instana_client.models.adaptive_threshold_rule import AdaptiveThresholdRule
from instana_client.models.addition import Addition
from instana_client.models.adjusted_timeframe import AdjustedTimeframe
from instana_client.models.agent_configuration_update import AgentConfigurationUpdate
from instana_client.models.alerting_configuration import AlertingConfiguration
from instana_client.models.alerting_configuration_with_last_updated import AlertingConfigurationWithLastUpdated
from instana_client.models.alerting_time_window import AlertingTimeWindow
from instana_client.models.apdex_configuration import ApdexConfiguration
from instana_client.models.apdex_configuration_input import ApdexConfigurationInput
from instana_client.models.apdex_entity import ApdexEntity
from instana_client.models.apdex_report import ApdexReport
from instana_client.models.api_create_group import ApiCreateGroup
from instana_client.models.api_create_role import ApiCreateRole
from instana_client.models.api_group import ApiGroup
from instana_client.models.api_member import ApiMember
from instana_client.models.api_permission_set import ApiPermissionSet
from instana_client.models.api_restricted_application_filter import ApiRestrictedApplicationFilter
from instana_client.models.api_role import ApiRole
from instana_client.models.api_tag import ApiTag
from instana_client.models.api_team import ApiTeam
from instana_client.models.api_team_info import ApiTeamInfo
from instana_client.models.api_team_member import ApiTeamMember
from instana_client.models.api_team_role import ApiTeamRole
from instana_client.models.api_team_scope import ApiTeamScope
from instana_client.models.api_token import ApiToken
from instana_client.models.app_data_metric_configuration import AppDataMetricConfiguration
from instana_client.models.application import Application
from instana_client.models.application_alert_config import ApplicationAlertConfig
from instana_client.models.application_alert_config_with_metadata import ApplicationAlertConfigWithMetadata
from instana_client.models.application_alert_rule import ApplicationAlertRule
from instana_client.models.application_apdex_entity import ApplicationApdexEntity
from instana_client.models.application_config import ApplicationConfig
from instana_client.models.application_event_result import ApplicationEventResult
from instana_client.models.application_item import ApplicationItem
from instana_client.models.application_metric_result import ApplicationMetricResult
from instana_client.models.application_node import ApplicationNode
from instana_client.models.application_result import ApplicationResult
from instana_client.models.application_scope import ApplicationScope
from instana_client.models.application_scope_with_metadata import ApplicationScopeWithMetadata
from instana_client.models.application_sli_entity import ApplicationSliEntity
from instana_client.models.application_slo_entity import ApplicationSloEntity
from instana_client.models.application_time_threshold import ApplicationTimeThreshold
from instana_client.models.arithmetic_configuration import ArithmeticConfiguration
from instana_client.models.arithmetic_operand import ArithmeticOperand
from instana_client.models.arithmetic_operation import ArithmeticOperation
from instana_client.models.audit_log_entry import AuditLogEntry
from instana_client.models.audit_log_ui_response import AuditLogUiResponse
from instana_client.models.author import Author
from instana_client.models.availability_blueprint_indicator import AvailabilityBlueprintIndicator
from instana_client.models.availability_sli_entity import AvailabilitySliEntity
from instana_client.models.available_metrics import AvailableMetrics
from instana_client.models.available_plugins import AvailablePlugins
from instana_client.models.backend_trace_reference import BackendTraceReference
from instana_client.models.bidirectional_ms_teams_app_integration import BidirectionalMsTeamsAppIntegration
from instana_client.models.bidirectional_slack_app_integration import BidirectionalSlackAppIntegration
from instana_client.models.binary_operator_dto import BinaryOperatorDTO
from instana_client.models.browser_script_configuration import BrowserScriptConfiguration
from instana_client.models.browser_script_configuration_update import BrowserScriptConfigurationUpdate
from instana_client.models.built_in_event_specification import BuiltInEventSpecification
from instana_client.models.built_in_event_specification_with_last_updated import BuiltInEventSpecificationWithLastUpdated
from instana_client.models.business_activity import BusinessActivity
from instana_client.models.business_perspective_config import BusinessPerspectiveConfig
from instana_client.models.call_groups_item import CallGroupsItem
from instana_client.models.call_groups_result import CallGroupsResult
from instana_client.models.call_relation import CallRelation
from instana_client.models.change_summary import ChangeSummary
from instana_client.models.cloudfoundry_physical_context import CloudfoundryPhysicalContext
from instana_client.models.condition import Condition
from instana_client.models.config_version import ConfigVersion
from instana_client.models.correction import Correction
from instana_client.models.correction_configuration import CorrectionConfiguration
from instana_client.models.correction_scheduling import CorrectionScheduling
from instana_client.models.correction_window import CorrectionWindow
from instana_client.models.crash_mobile_app_alert_rule import CrashMobileAppAlertRule
from instana_client.models.create_website_request_inner import CreateWebsiteRequestInner
from instana_client.models.cursor_paginated_business_activity_item import CursorPaginatedBusinessActivityItem
from instana_client.models.cursor_pagination import CursorPagination
from instana_client.models.cursor_pagination_infra_explore_cursor import CursorPaginationInfraExploreCursor
from instana_client.models.custom_blueprint_indicator import CustomBlueprintIndicator
from instana_client.models.custom_dashboard import CustomDashboard
from instana_client.models.custom_dashboard_preview import CustomDashboardPreview
from instana_client.models.custom_dashboard_with_user_specific_information import CustomDashboardWithUserSpecificInformation
from instana_client.models.custom_dependency import CustomDependency
from instana_client.models.custom_email_subject_prefix import CustomEmailSubjectPrefix
from instana_client.models.custom_entity_model import CustomEntityModel
from instana_client.models.custom_entity_with_metadata import CustomEntityWithMetadata
from instana_client.models.custom_event_mobile_app_alert_rule import CustomEventMobileAppAlertRule
from instana_client.models.custom_event_specification import CustomEventSpecification
from instana_client.models.custom_event_specification_with_last_updated import CustomEventSpecificationWithLastUpdated
from instana_client.models.custom_event_website_alert_rule import CustomEventWebsiteAlertRule
from instana_client.models.custom_metric import CustomMetric
from instana_client.models.custom_payload_configuration import CustomPayloadConfiguration
from instana_client.models.custom_payload_field import CustomPayloadField
from instana_client.models.custom_payload_with_last_updated import CustomPayloadWithLastUpdated
from instana_client.models.custom_payload_with_version import CustomPayloadWithVersion
from instana_client.models.dns_configuration import DNSConfiguration
from instana_client.models.dns_configuration_update import DNSConfigurationUpdate
from instana_client.models.dns_filter_query_time import DNSFilterQueryTime
from instana_client.models.dns_filter_target_value import DNSFilterTargetValue
from instana_client.models.dashboard_api_token import DashboardApiToken
from instana_client.models.database_integration import DatabaseIntegration
from instana_client.models.deprecated_tag_filter import DeprecatedTagFilter
from instana_client.models.division import Division
from instana_client.models.duration import Duration
from instana_client.models.dynamic_field import DynamicField
from instana_client.models.dynamic_field_value import DynamicFieldValue
from instana_client.models.dynamic_parameter import DynamicParameter
from instana_client.models.edit_user import EditUser
from instana_client.models.email_integration import EmailIntegration
from instana_client.models.empty_configuration import EmptyConfiguration
from instana_client.models.endpoint import Endpoint
from instana_client.models.endpoint_config import EndpointConfig
from instana_client.models.endpoint_event_result import EndpointEventResult
from instana_client.models.endpoint_item import EndpointItem
from instana_client.models.endpoint_metric_result import EndpointMetricResult
from instana_client.models.endpoint_node import EndpointNode
from instana_client.models.endpoint_result import EndpointResult
from instana_client.models.endpoint_simple import EndpointSimple
from instana_client.models.entity_count_rule import EntityCountRule
from instana_client.models.entity_count_verification_rule import EntityCountVerificationRule
from instana_client.models.entity_health_info import EntityHealthInfo
from instana_client.models.entity_id import EntityId
from instana_client.models.entity_verification_rule import EntityVerificationRule
from instana_client.models.error_budget_alert_rule import ErrorBudgetAlertRule
from instana_client.models.errors_application_alert_rule import ErrorsApplicationAlertRule
from instana_client.models.event import Event
from instana_client.models.event_filtering_configuration import EventFilteringConfiguration
from instana_client.models.event_result import EventResult
from instana_client.models.event_specification_info import EventSpecificationInfo
from instana_client.models.extended_service import ExtendedService
from instana_client.models.failure_synthetic_alert_rule import FailureSyntheticAlertRule
from instana_client.models.fixed_http_path_segment_matching_rule import FixedHttpPathSegmentMatchingRule
from instana_client.models.fixed_time_window import FixedTimeWindow
from instana_client.models.generic_infra_alert_rule import GenericInfraAlertRule
from instana_client.models.geo_location_configuration import GeoLocationConfiguration
from instana_client.models.geo_mapping_rule import GeoMappingRule
from instana_client.models.geo_subdivision import GeoSubdivision
from instana_client.models.get_activities import GetActivities
from instana_client.models.get_application_metrics import GetApplicationMetrics
from instana_client.models.get_applications import GetApplications
from instana_client.models.get_available_metrics_query import GetAvailableMetricsQuery
from instana_client.models.get_available_plugins_query import GetAvailablePluginsQuery
from instana_client.models.get_call_groups import GetCallGroups
from instana_client.models.get_combined_metrics import GetCombinedMetrics
from instana_client.models.get_dynamic_parameter_values import GetDynamicParameterValues
from instana_client.models.get_endpoints import GetEndpoints
from instana_client.models.get_infrastructure_groups_query import GetInfrastructureGroupsQuery
from instana_client.models.get_infrastructure_query import GetInfrastructureQuery
from instana_client.models.get_metrics_result import GetMetricsResult
from instana_client.models.get_mobile_app_beacon_groups import GetMobileAppBeaconGroups
from instana_client.models.get_mobile_app_beacons import GetMobileAppBeacons
from instana_client.models.get_mobile_app_metrics import GetMobileAppMetrics
from instana_client.models.get_mobile_app_metrics_v2 import GetMobileAppMetricsV2
from instana_client.models.get_payload_keys_result import GetPayloadKeysResult
from instana_client.models.get_services import GetServices
from instana_client.models.get_snapshots_query import GetSnapshotsQuery
from instana_client.models.get_test_result import GetTestResult
from instana_client.models.get_test_result_analytic import GetTestResultAnalytic
from instana_client.models.get_test_result_base import GetTestResultBase
from instana_client.models.get_test_result_list import GetTestResultList
from instana_client.models.get_test_summary_result import GetTestSummaryResult
from instana_client.models.get_trace_download_result_item import GetTraceDownloadResultItem
from instana_client.models.get_trace_groups import GetTraceGroups
from instana_client.models.get_traces import GetTraces
from instana_client.models.get_website_beacon_groups import GetWebsiteBeaconGroups
from instana_client.models.get_website_beacons import GetWebsiteBeacons
from instana_client.models.get_website_metrics import GetWebsiteMetrics
from instana_client.models.get_website_metrics_v2 import GetWebsiteMetricsV2
from instana_client.models.global_application_alert_config_with_metadata import GlobalApplicationAlertConfigWithMetadata
from instana_client.models.global_applications_alert_config import GlobalApplicationsAlertConfig
from instana_client.models.google_chat_integration import GoogleChatIntegration
from instana_client.models.graph_edge import GraphEdge
from instana_client.models.graph_node import GraphNode
from instana_client.models.group import Group
from instana_client.models.group_by_tag import GroupByTag
from instana_client.models.group_mapping import GroupMapping
from instana_client.models.group_mapping_overview import GroupMappingOverview
from instana_client.models.health_state import HealthState
from instana_client.models.historic_baseline import HistoricBaseline
from instana_client.models.host_availability_rule import HostAvailabilityRule
from instana_client.models.http_action_configuration import HttpActionConfiguration
from instana_client.models.http_action_configuration_update import HttpActionConfigurationUpdate
from instana_client.models.http_endpoint_config import HttpEndpointConfig
from instana_client.models.http_endpoint_rule import HttpEndpointRule
from instana_client.models.http_path_segment_matching_rule import HttpPathSegmentMatchingRule
from instana_client.models.http_script_configuration import HttpScriptConfiguration
from instana_client.models.http_script_configuration_update import HttpScriptConfigurationUpdate
from instana_client.models.hyper_param import HyperParam
from instana_client.models.identity_provider_patch import IdentityProviderPatch
from instana_client.models.impacted_beacon_info import ImpactedBeaconInfo
from instana_client.models.infra_alert_config import InfraAlertConfig
from instana_client.models.infra_alert_config_with_metadata import InfraAlertConfigWithMetadata
from instana_client.models.infra_alert_rule import InfraAlertRule
from instana_client.models.infra_event_result import InfraEventResult
from instana_client.models.infra_metric_configuration import InfraMetricConfiguration
from instana_client.models.infra_slo_entity import InfraSloEntity
from instana_client.models.infra_time_threshold import InfraTimeThreshold
from instana_client.models.infrastructure_entities_result import InfrastructureEntitiesResult
from instana_client.models.infrastructure_group import InfrastructureGroup
from instana_client.models.infrastructure_groups_result import InfrastructureGroupsResult
from instana_client.models.infrastructure_item import InfrastructureItem
from instana_client.models.infrastructure_metric_result import InfrastructureMetricResult
from instana_client.models.instana_version_info import InstanaVersionInfo
from instana_client.models.integration_overview import IntegrationOverview
from instana_client.models.invitation import Invitation
from instana_client.models.invitation_response import InvitationResponse
from instana_client.models.invitation_result import InvitationResult
from instana_client.models.ip_masking_configuration import IpMaskingConfiguration
from instana_client.models.js_stack_trace_line import JsStackTraceLine
from instana_client.models.kubernetes_physical_context import KubernetesPhysicalContext
from instana_client.models.llm_egress_gateway import LLMEgressGateway
from instana_client.models.latency_blueprint_indicator import LatencyBlueprintIndicator
from instana_client.models.location_status import LocationStatus
from instana_client.models.log_alert_config import LogAlertConfig
from instana_client.models.log_alert_config_with_metadata import LogAlertConfigWithMetadata
from instana_client.models.log_alert_rule import LogAlertRule
from instana_client.models.log_count_alert_rule import LogCountAlertRule
from instana_client.models.log_entry_actor import LogEntryActor
from instana_client.models.log_event_result import LogEventResult
from instana_client.models.log_time_threshold import LogTimeThreshold
from instana_client.models.log_volume_group import LogVolumeGroup
from instana_client.models.log_volume_usage_item import LogVolumeUsageItem
from instana_client.models.log_volume_usage_result import LogVolumeUsageResult
from instana_client.models.logs_application_alert_rule import LogsApplicationAlertRule
from instana_client.models.maintenance_config import MaintenanceConfig
from instana_client.models.maintenance_config_scheduling import MaintenanceConfigScheduling
from instana_client.models.maintenance_config_v2 import MaintenanceConfigV2
from instana_client.models.maintenance_config_v2_with_state_and_occurrence import MaintenanceConfigV2WithStateAndOccurrence
from instana_client.models.maintenance_config_with_last_updated import MaintenanceConfigWithLastUpdated
from instana_client.models.maintenance_window import MaintenanceWindow
from instana_client.models.manual_alerting_channel_configuration import ManualAlertingChannelConfiguration
from instana_client.models.manual_close_info import ManualCloseInfo
from instana_client.models.manual_service_config import ManualServiceConfig
from instana_client.models.match_all_http_path_segment_matching_rule import MatchAllHttpPathSegmentMatchingRule
from instana_client.models.match_expression_dto import MatchExpressionDTO
from instana_client.models.meta_data import MetaData
from instana_client.models.metric_api_result import MetricAPIResult
from instana_client.models.metric_config import MetricConfig
from instana_client.models.metric_configuration import MetricConfiguration
from instana_client.models.metric_description import MetricDescription
from instana_client.models.metric_instance import MetricInstance
from instana_client.models.metric_item import MetricItem
from instana_client.models.metric_metadata import MetricMetadata
from instana_client.models.metric_pattern import MetricPattern
from instana_client.models.metric_query import MetricQuery
from instana_client.models.metrics_result import MetricsResult
from instana_client.models.metrics_result_item import MetricsResultItem
from instana_client.models.metrics_test_result_item import MetricsTestResultItem
from instana_client.models.mobile_app import MobileApp
from instana_client.models.mobile_app_alert_config import MobileAppAlertConfig
from instana_client.models.mobile_app_alert_rule import MobileAppAlertRule
from instana_client.models.mobile_app_beacon_groups_item import MobileAppBeaconGroupsItem
from instana_client.models.mobile_app_beacon_groups_result import MobileAppBeaconGroupsResult
from instana_client.models.mobile_app_beacon_result import MobileAppBeaconResult
from instana_client.models.mobile_app_beacon_tag_group import MobileAppBeaconTagGroup
from instana_client.models.mobile_app_beacons_item import MobileAppBeaconsItem
from instana_client.models.mobile_app_event_result import MobileAppEventResult
from instana_client.models.mobile_app_metric_result import MobileAppMetricResult
from instana_client.models.mobile_app_monitoring_beacon import MobileAppMonitoringBeacon
from instana_client.models.mobile_app_monitoring_metric_description import MobileAppMonitoringMetricDescription
from instana_client.models.mobile_app_monitoring_metrics_configuration import MobileAppMonitoringMetricsConfiguration
from instana_client.models.mobile_app_time_threshold import MobileAppTimeThreshold
from instana_client.models.model_field import ModelField
from instana_client.models.monitored_entities_stats import MonitoredEntitiesStats
from instana_client.models.monitoring_state import MonitoringState
from instana_client.models.multiple_scripts_configuration import MultipleScriptsConfiguration
from instana_client.models.multiplication import Multiplication
from instana_client.models.nested_operation import NestedOperation
from instana_client.models.new_application_config import NewApplicationConfig
from instana_client.models.new_business_perspective_config import NewBusinessPerspectiveConfig
from instana_client.models.new_manual_service_config import NewManualServiceConfig
from instana_client.models.o_auth_config import OAuthConfig
from instana_client.models.o_auth_integration import OAuthIntegration
from instana_client.models.o_auth_token import OAuthToken
from instana_client.models.occurrence import Occurrence
from instana_client.models.office365_integration import Office365Integration
from instana_client.models.one_time_maintenance_window import OneTimeMaintenanceWindow
from instana_client.models.opsgenie_integration import OpsgenieIntegration
from instana_client.models.order import Order
from instana_client.models.pagerduty_integration import PagerdutyIntegration
from instana_client.models.paginated_result import PaginatedResult
from instana_client.models.pagination import Pagination
from instana_client.models.parameter import Parameter
from instana_client.models.parameter_value import ParameterValue
from instana_client.models.path_parameter_http_path_segment_matching_rule import PathParameterHttpPathSegmentMatchingRule
from instana_client.models.physical_context import PhysicalContext
from instana_client.models.plugin_result import PluginResult
from instana_client.models.policy import Policy
from instana_client.models.policy_runnable import PolicyRunnable
from instana_client.models.policy_scheduling import PolicyScheduling
from instana_client.models.post_mobile_app_source_map_config_request import PostMobileAppSourceMapConfigRequest
from instana_client.models.post_snapshots_result import PostSnapshotsResult
from instana_client.models.problem import Problem
from instana_client.models.prometheus_webhook_integration import PrometheusWebhookIntegration
from instana_client.models.recurrent_maintenance_window import RecurrentMaintenanceWindow
from instana_client.models.release import Release
from instana_client.models.release_scope import ReleaseScope
from instana_client.models.release_with_metadata import ReleaseWithMetadata
from instana_client.models.retention_period import RetentionPeriod
from instana_client.models.rolling_time_window import RollingTimeWindow
from instana_client.models.rule_input import RuleInput
from instana_client.models.rule_with_threshold_application_alert_rule import RuleWithThresholdApplicationAlertRule
from instana_client.models.rule_with_threshold_infra_alert_rule import RuleWithThresholdInfraAlertRule
from instana_client.models.rule_with_threshold_log_alert_rule import RuleWithThresholdLogAlertRule
from instana_client.models.rule_with_threshold_mobile_app_alert_rule import RuleWithThresholdMobileAppAlertRule
from instana_client.models.rule_with_threshold_website_alert_rule import RuleWithThresholdWebsiteAlertRule
from instana_client.models.run_configuration import RunConfiguration
from instana_client.models.slo_config_with_rbac_tag import SLOConfigWithRBACTag
from instana_client.models.ssl_certificate_configuration import SSLCertificateConfiguration
from instana_client.models.ssl_certificate_configuration_update import SSLCertificateConfigurationUpdate
from instana_client.models.ssl_certificate_validation import SSLCertificateValidation
from instana_client.models.salesforce_integration import SalesforceIntegration
from instana_client.models.saturation_blueprint_indicator import SaturationBlueprintIndicator
from instana_client.models.scope_binding import ScopeBinding
from instana_client.models.search_field_result import SearchFieldResult
from instana_client.models.service import Service
from instana_client.models.service_config import ServiceConfig
from instana_client.models.service_event_result import ServiceEventResult
from instana_client.models.service_item import ServiceItem
from instana_client.models.service_level_indicator import ServiceLevelIndicator
from instana_client.models.service_level_objective_alert_rule import ServiceLevelObjectiveAlertRule
from instana_client.models.service_levels_alert_config import ServiceLevelsAlertConfig
from instana_client.models.service_levels_alert_rule import ServiceLevelsAlertRule
from instana_client.models.service_levels_burn_rate_config import ServiceLevelsBurnRateConfig
from instana_client.models.service_levels_burn_rate_time_windows import ServiceLevelsBurnRateTimeWindows
from instana_client.models.service_levels_static_threshold_config import ServiceLevelsStaticThresholdConfig
from instana_client.models.service_levels_time_threshold import ServiceLevelsTimeThreshold
from instana_client.models.service_levelse_alert_config_with_metadata import ServiceLevelseAlertConfigWithMetadata
from instana_client.models.service_map import ServiceMap
from instana_client.models.service_map_connection import ServiceMapConnection
from instana_client.models.service_matching_rule import ServiceMatchingRule
from instana_client.models.service_metric_result import ServiceMetricResult
from instana_client.models.service_node import ServiceNode
from instana_client.models.service_now_enhanced_integration import ServiceNowEnhancedIntegration
from instana_client.models.service_now_integration import ServiceNowIntegration
from instana_client.models.service_result import ServiceResult
from instana_client.models.service_scope import ServiceScope
from instana_client.models.service_scope_with_metadata import ServiceScopeWithMetadata
from instana_client.models.service_scoped_to import ServiceScopedTo
from instana_client.models.service_scoped_to_with_metadata import ServiceScopedToWithMetadata
from instana_client.models.service_simple import ServiceSimple
from instana_client.models.session_settings import SessionSettings
from instana_client.models.simple_metric_configuration import SimpleMetricConfiguration
from instana_client.models.single_value import SingleValue
from instana_client.models.slack_integration import SlackIntegration
from instana_client.models.sli_configuration import SliConfiguration
from instana_client.models.sli_configuration_with_last_updated import SliConfigurationWithLastUpdated
from instana_client.models.sli_entity import SliEntity
from instana_client.models.sli_report import SliReport
from instana_client.models.slo_entity import SloEntity
from instana_client.models.slo_report import SloReport
from instana_client.models.slowness_application_alert_rule import SlownessApplicationAlertRule
from instana_client.models.slowness_mobile_app_alert_rule import SlownessMobileAppAlertRule
from instana_client.models.slowness_website_alert_rule import SlownessWebsiteAlertRule
from instana_client.models.snapshot_item import SnapshotItem
from instana_client.models.snapshot_preview import SnapshotPreview
from instana_client.models.snapshot_result import SnapshotResult
from instana_client.models.software_user import SoftwareUser
from instana_client.models.software_version import SoftwareVersion
from instana_client.models.source_map_file_blob import SourceMapFileBlob
from instana_client.models.source_map_file_meta import SourceMapFileMeta
from instana_client.models.source_map_upload_config import SourceMapUploadConfig
from instana_client.models.source_map_upload_configs import SourceMapUploadConfigs
from instana_client.models.span_excerpt import SpanExcerpt
from instana_client.models.span_relation import SpanRelation
from instana_client.models.specific_js_errors_website_alert_rule import SpecificJsErrorsWebsiteAlertRule
from instana_client.models.splunk_integration import SplunkIntegration
from instana_client.models.stack_trace_item import StackTraceItem
from instana_client.models.stack_trace_line import StackTraceLine
from instana_client.models.static_baseline_threshold_rule import StaticBaselineThresholdRule
from instana_client.models.static_string_field import StaticStringField
from instana_client.models.static_threshold import StaticThreshold
from instana_client.models.static_threshold_rule import StaticThresholdRule
from instana_client.models.status_code_application_alert_rule import StatusCodeApplicationAlertRule
from instana_client.models.status_code_mobile_app_alert_rule import StatusCodeMobileAppAlertRule
from instana_client.models.status_code_website_alert_rule import StatusCodeWebsiteAlertRule
from instana_client.models.subtraction import Subtraction
from instana_client.models.synthetic_alert_config import SyntheticAlertConfig
from instana_client.models.synthetic_alert_config_with_metadata import SyntheticAlertConfigWithMetadata
from instana_client.models.synthetic_alert_rule import SyntheticAlertRule
from instana_client.models.synthetic_bulk_response import SyntheticBulkResponse
from instana_client.models.synthetic_call_config import SyntheticCallConfig
from instana_client.models.synthetic_call_rule import SyntheticCallRule
from instana_client.models.synthetic_call_with_defaults_config import SyntheticCallWithDefaultsConfig
from instana_client.models.synthetic_configuration import SyntheticConfiguration
from instana_client.models.synthetic_configuration_update import SyntheticConfigurationUpdate
from instana_client.models.synthetic_credential import SyntheticCredential
from instana_client.models.synthetic_datacenter import SyntheticDatacenter
from instana_client.models.synthetic_datacenter_configuration import SyntheticDatacenterConfiguration
from instana_client.models.synthetic_geo_point import SyntheticGeoPoint
from instana_client.models.synthetic_location import SyntheticLocation
from instana_client.models.synthetic_location_configuration import SyntheticLocationConfiguration
from instana_client.models.synthetic_metric_configuration import SyntheticMetricConfiguration
from instana_client.models.synthetic_metric_tag_group import SyntheticMetricTagGroup
from instana_client.models.synthetic_playback_capabilities import SyntheticPlaybackCapabilities
from instana_client.models.synthetic_resource_update_list_dns_filter_target_value_list_dns_filter_target_value import SyntheticResourceUpdateListDNSFilterTargetValueListDNSFilterTargetValue
from instana_client.models.synthetic_resource_update_list_ssl_certificate_validation_list_ssl_certificate_validation import SyntheticResourceUpdateListSSLCertificateValidationListSSLCertificateValidation
from instana_client.models.synthetic_resource_update_list_string_list_string import SyntheticResourceUpdateListStringListString
from instana_client.models.synthetic_resource_update_map_string_string_list_string import SyntheticResourceUpdateMapStringStringListString
from instana_client.models.synthetic_slo_entity import SyntheticSloEntity
from instana_client.models.synthetic_test import SyntheticTest
from instana_client.models.synthetic_test_cicd import SyntheticTestCICD
from instana_client.models.synthetic_test_cicd_customization import SyntheticTestCICDCustomization
from instana_client.models.synthetic_test_cicd_item import SyntheticTestCICDItem
from instana_client.models.synthetic_test_cicd_response import SyntheticTestCICDResponse
from instana_client.models.synthetic_test_deep_update import SyntheticTestDeepUpdate
from instana_client.models.synthetic_test_shallow_update import SyntheticTestShallowUpdate
from instana_client.models.synthetic_test_update import SyntheticTestUpdate
from instana_client.models.synthetic_time_threshold import SyntheticTimeThreshold
from instana_client.models.synthetic_type_configuration import SyntheticTypeConfiguration
from instana_client.models.synthetic_type_configuration_update import SyntheticTypeConfigurationUpdate
from instana_client.models.synthetics_event_result import SyntheticsEventResult
from instana_client.models.system_rule import SystemRule
from instana_client.models.system_rule_label import SystemRuleLabel
from instana_client.models.tag import Tag
from instana_client.models.tag_catalog import TagCatalog
from instana_client.models.tag_filter import TagFilter
from instana_client.models.tag_filter_expression import TagFilterExpression
from instana_client.models.tag_filter_expression_element import TagFilterExpressionElement
from instana_client.models.tag_matcher_dto import TagMatcherDTO
from instana_client.models.tag_tree_level import TagTreeLevel
from instana_client.models.tag_tree_node import TagTreeNode
from instana_client.models.tag_tree_tag import TagTreeTag
from instana_client.models.test_common_properties import TestCommonProperties
from instana_client.models.test_last_error import TestLastError
from instana_client.models.test_result import TestResult
from instana_client.models.test_result_common_properties import TestResultCommonProperties
from instana_client.models.test_result_detail_data import TestResultDetailData
from instana_client.models.test_result_item import TestResultItem
from instana_client.models.test_result_list_item import TestResultListItem
from instana_client.models.test_result_list_result import TestResultListResult
from instana_client.models.test_result_metadata import TestResultMetadata
from instana_client.models.test_result_subtransaction import TestResultSubtransaction
from instana_client.models.threshold import Threshold
from instana_client.models.threshold_config_rule import ThresholdConfigRule
from instana_client.models.threshold_rule import ThresholdRule
from instana_client.models.throughput_application_alert_rule import ThroughputApplicationAlertRule
from instana_client.models.throughput_mobile_app_alert_rule import ThroughputMobileAppAlertRule
from instana_client.models.throughput_website_alert_rule import ThroughputWebsiteAlertRule
from instana_client.models.time_frame import TimeFrame
from instana_client.models.time_window import TimeWindow
from instana_client.models.topology import Topology
from instana_client.models.trace import Trace
from instana_client.models.trace_activity_tree_node_details import TraceActivityTreeNodeDetails
from instana_client.models.trace_download_result import TraceDownloadResult
from instana_client.models.trace_groups_item import TraceGroupsItem
from instana_client.models.trace_groups_result import TraceGroupsResult
from instana_client.models.trace_impact_application_time_threshold import TraceImpactApplicationTimeThreshold
from instana_client.models.trace_item import TraceItem
from instana_client.models.trace_result import TraceResult
from instana_client.models.traffic_blueprint_indicator import TrafficBlueprintIndicator
from instana_client.models.trigger import Trigger
from instana_client.models.type_configuration import TypeConfiguration
from instana_client.models.unsupported_http_path_segment_matching_rule import UnsupportedHttpPathSegmentMatchingRule
from instana_client.models.updated_business_perspective_config import UpdatedBusinessPerspectiveConfig
from instana_client.models.usage_result import UsageResult
from instana_client.models.usage_result_items import UsageResultItems
from instana_client.models.user_basic_result import UserBasicResult
from instana_client.models.user_impact_mobile_app_time_threshold import UserImpactMobileAppTimeThreshold
from instana_client.models.user_impact_website_time_threshold import UserImpactWebsiteTimeThreshold
from instana_client.models.user_result import UserResult
from instana_client.models.users_result import UsersResult
from instana_client.models.validated_alerting_channel_input_info import ValidatedAlertingChannelInputInfo
from instana_client.models.validated_alerting_configuration import ValidatedAlertingConfiguration
from instana_client.models.validated_maintenance_config_v2_with_state_and_occurrence import ValidatedMaintenanceConfigV2WithStateAndOccurrence
from instana_client.models.validated_maintenance_config_with_status import ValidatedMaintenanceConfigWithStatus
from instana_client.models.victor_ops_integration import VictorOpsIntegration
from instana_client.models.violations_in_period_application_time_threshold import ViolationsInPeriodApplicationTimeThreshold
from instana_client.models.violations_in_period_mobile_app_time_threshold import ViolationsInPeriodMobileAppTimeThreshold
from instana_client.models.violations_in_period_website_time_threshold import ViolationsInPeriodWebsiteTimeThreshold
from instana_client.models.violations_in_sequence_application_time_threshold import ViolationsInSequenceApplicationTimeThreshold
from instana_client.models.violations_in_sequence_infra_time_threshold import ViolationsInSequenceInfraTimeThreshold
from instana_client.models.violations_in_sequence_log_time_threshold import ViolationsInSequenceLogTimeThreshold
from instana_client.models.violations_in_sequence_mobile_app_time_threshold import ViolationsInSequenceMobileAppTimeThreshold
from instana_client.models.violations_in_sequence_synthetic_time_threshold import ViolationsInSequenceSyntheticTimeThreshold
from instana_client.models.violations_in_sequence_website_time_threshold import ViolationsInSequenceWebsiteTimeThreshold
from instana_client.models.watson_ai_ops_webhook_integration import WatsonAIOpsWebhookIntegration
from instana_client.models.webex_teams_webhook_integration import WebexTeamsWebhookIntegration
from instana_client.models.webhook_integration import WebhookIntegration
from instana_client.models.webpage_action_configuration import WebpageActionConfiguration
from instana_client.models.webpage_action_configuration_update import WebpageActionConfigurationUpdate
from instana_client.models.webpage_script_configuration import WebpageScriptConfiguration
from instana_client.models.webpage_script_configuration_update import WebpageScriptConfigurationUpdate
from instana_client.models.website import Website
from instana_client.models.website_alert_config import WebsiteAlertConfig
from instana_client.models.website_alert_config_with_metadata import WebsiteAlertConfigWithMetadata
from instana_client.models.website_alert_rule import WebsiteAlertRule
from instana_client.models.website_apdex_entity import WebsiteApdexEntity
from instana_client.models.website_beacon_groups_item import WebsiteBeaconGroupsItem
from instana_client.models.website_beacon_groups_result import WebsiteBeaconGroupsResult
from instana_client.models.website_beacon_result import WebsiteBeaconResult
from instana_client.models.website_beacon_tag_group import WebsiteBeaconTagGroup
from instana_client.models.website_beacons_item import WebsiteBeaconsItem
from instana_client.models.website_event_based_sli_entity import WebsiteEventBasedSliEntity
from instana_client.models.website_event_result import WebsiteEventResult
from instana_client.models.website_metric_result import WebsiteMetricResult
from instana_client.models.website_monitoring_beacon import WebsiteMonitoringBeacon
from instana_client.models.website_monitoring_metric_description import WebsiteMonitoringMetricDescription
from instana_client.models.website_monitoring_metrics_configuration import WebsiteMonitoringMetricsConfiguration
from instana_client.models.website_slo_entity import WebsiteSloEntity
from instana_client.models.website_time_based_sli_entity import WebsiteTimeBasedSliEntity
from instana_client.models.website_time_threshold import WebsiteTimeThreshold
from instana_client.models.widget import Widget
from instana_client.models.with_metadata import WithMetadata
from instana_client.models.with_resolved_name import WithResolvedName
from instana_client.models.z_chat_ops_integration import ZChatOpsIntegration



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.synthetic_test_playback_results_api import SyntheticTestPlaybackResultsApi


class TestSyntheticTestPlaybackResultsApi(unittest.TestCase):
    """SyntheticTestPlaybackResultsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SyntheticTestPlaybackResultsApi()

    def tearDown(self) -> None:
        pass

    def test_get_location_summary_list(self) -> None:
        """Test case for get_location_summary_list

        Get a list of Synthetic locations with last run test on each location data
        """
        pass

    def test_get_synthetic_result(self) -> None:
        """Test case for get_synthetic_result

        Get Synthetic test playback results
        """
        pass

    def test_get_synthetic_result_analytic(self) -> None:
        """Test case for get_synthetic_result_analytic

        Get a list of Synthetic tests based on the specified analytic function
        """
        pass

    def test_get_synthetic_result_detail_data(self) -> None:
        """Test case for get_synthetic_result_detail_data

        Get Synthetic test playback result detail data
        """
        pass

    def test_get_synthetic_result_detail_data_file(self) -> None:
        """Test case for get_synthetic_result_detail_data_file

        Download the synthetic test playback result detail data file
        """
        pass

    def test_get_synthetic_result_list(self) -> None:
        """Test case for get_synthetic_result_list

        Get a list of Synthetic test playback results
        """
        pass

    def test_get_synthetic_result_metadata(self) -> None:
        """Test case for get_synthetic_result_metadata

        Get Synthetic test playback detail result description(metadata)
        """
        pass

    def test_get_test_summary_list(self) -> None:
        """Test case for get_test_summary_list

        Get a list of Synthetic tests with success rate and average response time data
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from instana_client.models.policy import Policy

from instana_client.api_client import ApiClient, RequestSerialized
from instana_client.api_response import ApiResponse
from instana_client.rest import RESTResponseType


class PoliciesApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def add_policies(
        self,
        policy: List[Policy],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Policy]:
        """Create automation policies.

        Creates a list of automation policies. Policy creation requires `Configuration of automation policies` permission.

        :param policy: (required)
        :type policy: List[Policy]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_policies_serialize(
            policy=policy,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "List[Policy]",
            '400': None,
            '403': None,
            '412': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def add_policies_with_http_info(
        self,
        policy: List[Policy],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Policy]]:
        """Create automation policies.

        Creates a list of automation policies. Policy creation requires `Configuration of automation policies` permission.

        :param policy: (required)
        :type policy: List[Policy]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_policies_serialize(
            policy=policy,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "List[Policy]",
            '400': None,
            '403': None,
            '412': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def add_policies_without_preload_content(
        self,
        policy: List[Policy],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create automation policies.

        Creates a list of automation policies. Policy creation requires `Configuration of automation policies` permission.

        :param policy: (required)
        :type policy: List[Policy]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_policies_serialize(
            policy=policy,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "List[Policy]",
            '400': None,
            '403': None,
            '412': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _add_policies_serialize(
        self,
        policy,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'Policy': '',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if policy is not None:
            _body_params = policy


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/automation/policies/bulk',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def add_policy(
        self,
        policy: Policy,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Policy:
        """Create an automation policy.

        Creates a new automation policy. Policy creation requires `Configuration of automation policies` permission.

        :param policy: (required)
        :type policy: Policy
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_policy_serialize(
            policy=policy,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "Policy",
            '400': None,
            '403': None,
            '412': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def add_policy_with_http_info(
        self,
        policy: Policy,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Policy]:
        """Create an automation policy.

        Creates a new automation policy. Policy creation requires `Configuration of automation policies` permission.

        :param policy: (required)
        :type policy: Policy
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_policy_serialize(
            policy=policy,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "Policy",
            '400': None,
            '403': None,
            '412': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def add_policy_without_preload_content(
        self,
        policy: Policy,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create an automation policy.

        Creates a new automation policy. Policy creation requires `Configuration of automation policies` permission.

        :param policy: (required)
        :type policy: Policy
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._add_policy_serialize(
            policy=policy,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "Policy",
            '400': None,
            '403': None,
            '412': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _add_policy_serialize(
        self,
        policy,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if policy is not None:
            _body_params = policy


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/automation/policies',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_policy(
        self,
        id: Annotated[StrictStr, Field(description="Automation policy ID to delete")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Deletes an automation policy by identifier.

        Deletes an automation policy by identifier. Policy deletion requires `Configuration of automation policies` permission. When using personal tokens the automation policies deleted are based on the access set in `Limited access` permission settings.

        :param id: Automation policy ID to delete (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_policy_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '412': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_policy_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Automation policy ID to delete")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Deletes an automation policy by identifier.

        Deletes an automation policy by identifier. Policy deletion requires `Configuration of automation policies` permission. When using personal tokens the automation policies deleted are based on the access set in `Limited access` permission settings.

        :param id: Automation policy ID to delete (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_policy_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '412': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_policy_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Automation policy ID to delete")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Deletes an automation policy by identifier.

        Deletes an automation policy by identifier. Policy deletion requires `Configuration of automation policies` permission. When using personal tokens the automation policies deleted are based on the access set in `Limited access` permission settings.

        :param id: Automation policy ID to delete (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_policy_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
            '403': None,
            '412': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_policy_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/automation/policies/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_policies(
        self,
        trigger_type: Annotated[Optional[StrictStr], Field(description="Filter policies by the event or alert type that can trigger a policy. This is an optional parameter. Valid values are customEvent, builtinEvent, applicationSmartAlert, globalApplicationSmartAlert, websiteSmartAlert, infraSmartAlert, mobileAppSmartAlert, syntheticsSmartAlert, logSmartAlert, sloSmartAlert")] = None,
        trigger_id: Annotated[Optional[StrictStr], Field(description="Trigger identifier. This is an optional parameter.")] = None,
        execution_type: Annotated[Optional[StrictStr], Field(description="Filter policies by policy execution type. This is an optional parameter.  Valid values are automatic or manual")] = None,
        action_id: Annotated[Optional[StrictStr], Field(description="Filter policies by action ID. This is an optional parameter.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Policy]:
        """Get all automation policies.

        Returns all the automation policies filtered by the values in optional query parameters. When using personal access tokens, the user must have at least `Viewer` access for Automation and the automation policies returned are also filtered based on the access set in `Limited access` permission settings.

        :param trigger_type: Filter policies by the event or alert type that can trigger a policy. This is an optional parameter. Valid values are customEvent, builtinEvent, applicationSmartAlert, globalApplicationSmartAlert, websiteSmartAlert, infraSmartAlert, mobileAppSmartAlert, syntheticsSmartAlert, logSmartAlert, sloSmartAlert
        :type trigger_type: str
        :param trigger_id: Trigger identifier. This is an optional parameter.
        :type trigger_id: str
        :param execution_type: Filter policies by policy execution type. This is an optional parameter.  Valid values are automatic or manual
        :type execution_type: str
        :param action_id: Filter policies by action ID. This is an optional parameter.
        :type action_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_policies_serialize(
            trigger_type=trigger_type,
            trigger_id=trigger_id,
            execution_type=execution_type,
            action_id=action_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Policy]",
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_policies_with_http_info(
        self,
        trigger_type: Annotated[Optional[StrictStr], Field(description="Filter policies by the event or alert type that can trigger a policy. This is an optional parameter. Valid values are customEvent, builtinEvent, applicationSmartAlert, globalApplicationSmartAlert, websiteSmartAlert, infraSmartAlert, mobileAppSmartAlert, syntheticsSmartAlert, logSmartAlert, sloSmartAlert")] = None,
        trigger_id: Annotated[Optional[StrictStr], Field(description="Trigger identifier. This is an optional parameter.")] = None,
        execution_type: Annotated[Optional[StrictStr], Field(description="Filter policies by policy execution type. This is an optional parameter.  Valid values are automatic or manual")] = None,
        action_id: Annotated[Optional[StrictStr], Field(description="Filter policies by action ID. This is an optional parameter.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Policy]]:
        """Get all automation policies.

        Returns all the automation policies filtered by the values in optional query parameters. When using personal access tokens, the user must have at least `Viewer` access for Automation and the automation policies returned are also filtered based on the access set in `Limited access` permission settings.

        :param trigger_type: Filter policies by the event or alert type that can trigger a policy. This is an optional parameter. Valid values are customEvent, builtinEvent, applicationSmartAlert, globalApplicationSmartAlert, websiteSmartAlert, infraSmartAlert, mobileAppSmartAlert, syntheticsSmartAlert, logSmartAlert, sloSmartAlert
        :type trigger_type: str
        :param trigger_id: Trigger identifier. This is an optional parameter.
        :type trigger_id: str
        :param execution_type: Filter policies by policy execution type. This is an optional parameter.  Valid values are automatic or manual
        :type execution_type: str
        :param action_id: Filter policies by action ID. This is an optional parameter.
        :type action_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_policies_serialize(
            trigger_type=trigger_type,
            trigger_id=trigger_id,
            execution_type=execution_type,
            action_id=action_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Policy]",
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_policies_without_preload_content(
        self,
        trigger_type: Annotated[Optional[StrictStr], Field(description="Filter policies by the event or alert type that can trigger a policy. This is an optional parameter. Valid values are customEvent, builtinEvent, applicationSmartAlert, globalApplicationSmartAlert, websiteSmartAlert, infraSmartAlert, mobileAppSmartAlert, syntheticsSmartAlert, logSmartAlert, sloSmartAlert")] = None,
        trigger_id: Annotated[Optional[StrictStr], Field(description="Trigger identifier. This is an optional parameter.")] = None,
        execution_type: Annotated[Optional[StrictStr], Field(description="Filter policies by policy execution type. This is an optional parameter.  Valid values are automatic or manual")] = None,
        action_id: Annotated[Optional[StrictStr], Field(description="Filter policies by action ID. This is an optional parameter.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all automation policies.

        Returns all the automation policies filtered by the values in optional query parameters. When using personal access tokens, the user must have at least `Viewer` access for Automation and the automation policies returned are also filtered based on the access set in `Limited access` permission settings.

        :param trigger_type: Filter policies by the event or alert type that can trigger a policy. This is an optional parameter. Valid values are customEvent, builtinEvent, applicationSmartAlert, globalApplicationSmartAlert, websiteSmartAlert, infraSmartAlert, mobileAppSmartAlert, syntheticsSmartAlert, logSmartAlert, sloSmartAlert
        :type trigger_type: str
        :param trigger_id: Trigger identifier. This is an optional parameter.
        :type trigger_id: str
        :param execution_type: Filter policies by policy execution type. This is an optional parameter.  Valid values are automatic or manual
        :type execution_type: str
        :param action_id: Filter policies by action ID. This is an optional parameter.
        :type action_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_policies_serialize(
            trigger_type=trigger_type,
            trigger_id=trigger_id,
            execution_type=execution_type,
            action_id=action_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Policy]",
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_policies_serialize(
        self,
        trigger_type,
        trigger_id,
        execution_type,
        action_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if trigger_type is not None:
            
            _query_params.append(('triggerType', trigger_type))
            
        if trigger_id is not None:
            
            _query_params.append(('triggerId', trigger_id))
            
        if execution_type is not None:
            
            _query_params.append(('executionType', execution_type))
            
        if action_id is not None:
            
            _query_params.append(('actionId', action_id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/automation/policies',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_policy_by_id(
        self,
        id: Annotated[StrictStr, Field(description="Automation policy ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Policy:
        """Get an automation policy by ID.

        Returns the automation policy filtered by the ID in request parameter. When using personal access tokens, the user must have at least `Viewer` access for Automation and the automation policies returned are also filtered based on the access set in `Limited access` permission settings.

        :param id: Automation policy ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_policy_by_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Policy",
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_policy_by_id_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Automation policy ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Policy]:
        """Get an automation policy by ID.

        Returns the automation policy filtered by the ID in request parameter. When using personal access tokens, the user must have at least `Viewer` access for Automation and the automation policies returned are also filtered based on the access set in `Limited access` permission settings.

        :param id: Automation policy ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_policy_by_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Policy",
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_policy_by_id_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Automation policy ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get an automation policy by ID.

        Returns the automation policy filtered by the ID in request parameter. When using personal access tokens, the user must have at least `Viewer` access for Automation and the automation policies returned are also filtered based on the access set in `Limited access` permission settings.

        :param id: Automation policy ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_policy_by_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Policy",
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_policy_by_id_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/automation/policies/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_policy(
        self,
        id: StrictStr,
        policy: Policy,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Policy:
        """Updates an automation policy by identifier.

        Updates an automation policy by identifier. Policy updates requires `Configuration of automation policies` permission. When using personal tokens the automation policies updated are based on the access set in `Limited access` permission settings.

        :param id: (required)
        :type id: str
        :param policy: (required)
        :type policy: Policy
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_policy_serialize(
            id=id,
            policy=policy,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Policy",
            '403': None,
            '412': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_policy_with_http_info(
        self,
        id: StrictStr,
        policy: Policy,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Policy]:
        """Updates an automation policy by identifier.

        Updates an automation policy by identifier. Policy updates requires `Configuration of automation policies` permission. When using personal tokens the automation policies updated are based on the access set in `Limited access` permission settings.

        :param id: (required)
        :type id: str
        :param policy: (required)
        :type policy: Policy
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_policy_serialize(
            id=id,
            policy=policy,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Policy",
            '403': None,
            '412': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_policy_without_preload_content(
        self,
        id: StrictStr,
        policy: Policy,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Updates an automation policy by identifier.

        Updates an automation policy by identifier. Policy updates requires `Configuration of automation policies` permission. When using personal tokens the automation policies updated are based on the access set in `Limited access` permission settings.

        :param id: (required)
        :type id: str
        :param policy: (required)
        :type policy: Policy
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_policy_serialize(
            id=id,
            policy=policy,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Policy",
            '403': None,
            '412': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_policy_serialize(
        self,
        id,
        policy,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if policy is not None:
            _body_params = policy


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/automation/policies/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.topology import Topology

class TestTopology(unittest.TestCase):
    """Topology unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Topology:
        """Test Topology
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Topology`
        """
        model = Topology()
        if include_optional:
            return Topology(
                edges = [
                    instana_client.models.graph_edge.GraphEdge(
                        destination = '', 
                        relation = 'in', 
                        source = '', )
                    ],
                nodes = [
                    instana_client.models.graph_node.GraphNode(
                        data = {
                            'key' : None
                            }, 
                        entity_id = instana_client.models.entity_id.EntityId(
                            host = '', 
                            plugin_id = '', 
                            steady_id = '', ), 
                        id = '', 
                        label = '', 
                        plugin = '', )
                    ]
            )
        else:
            return Topology(
        )
        """

    def testTopology(self):
        """Test Topology"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.mobile_app_beacons_item import MobileAppBeaconsItem

class TestMobileAppBeaconsItem(unittest.TestCase):
    """MobileAppBeaconsItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MobileAppBeaconsItem:
        """Test MobileAppBeaconsItem
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MobileAppBeaconsItem`
        """
        model = MobileAppBeaconsItem()
        if include_optional:
            return MobileAppBeaconsItem(
                beacon = instana_client.models.mobile_app_monitoring_beacon.MobileAppMonitoringBeacon(
                    accuracy_radius = -1, 
                    agent_version = '', 
                    app_build = '', 
                    app_version = '', 
                    app_version_number = -1, 
                    available_mb = -1, 
                    backend_trace_id = '', 
                    batch_size = 1, 
                    beacon_id = '', 
                    bundle_identifier = '', 
                    bytes_ingested = 56, 
                    carrier = '', 
                    city = '', 
                    clock_skew = 0, 
                    cold_start_time_ms = -1, 
                    connection_type = '', 
                    continent = '', 
                    continent_code = '', 
                    country = '', 
                    country_code = '', 
                    current_app_state = '', 
                    custom_event_name = '', 
                    custom_metric = 1.337, 
                    decoded_body_size = -1, 
                    device_hardware = '', 
                    device_manufacturer = '', 
                    device_model = '', 
                    drop_view = '', 
                    duration = 0, 
                    effective_connection_type = '', 
                    encoded_body_size = -1, 
                    environment = '', 
                    error_count = 0, 
                    error_id = '', 
                    error_message = '', 
                    error_type = '', 
                    google_play_services_missing = True, 
                    hot_start_time_ms = -1, 
                    http_call_headers = {
                        'key' : ''
                        }, 
                    http_call_method = '', 
                    http_call_origin = '', 
                    http_call_path = '', 
                    http_call_status = -1, 
                    http_call_url = '', 
                    ingestion_time = 1, 
                    internal_meta = {
                        'key' : ''
                        }, 
                    label = '', 
                    latitude = 1.337, 
                    longitude = 1.337, 
                    max_mb = -1, 
                    meta = {
                        'key' : ''
                        }, 
                    mobile_app_id = '', 
                    mobile_app_label = '', 
                    os_name = '', 
                    os_version = '', 
                    parent_beacon_id = '', 
                    parsed_stack_trace = '', 
                    performance_subtype = '', 
                    platform = '', 
                    rate_limit_beacon_type = '', 
                    rate_limit_count = 0, 
                    rate_limit_custom_metric_val = [
                        1.337
                        ], 
                    rate_limit_time_max = 0, 
                    rate_limit_time_min = 0, 
                    region = '', 
                    rooted = True, 
                    session_id = '', 
                    stack_trace = '', 
                    stack_trace_key_checksum = '', 
                    stack_trace_key_information = '', 
                    stack_trace_line = [
                        instana_client.models.stack_trace_line.StackTraceLine(
                            column = -1, 
                            file = '', 
                            line = -1, 
                            name = '', 
                            translation_explanation = '', 
                            translation_status = -1, )
                        ], 
                    stack_trace_parsing_status = -1, 
                    subdivision = '', 
                    subdivision_code = '', 
                    tenant = '', 
                    timestamp = 1, 
                    transfer_size = -1, 
                    type = '', 
                    unit = '', 
                    use_features = [
                        ''
                        ], 
                    used_mb = -1, 
                    user_email = '', 
                    user_id = '', 
                    user_ip = '', 
                    user_languages = [
                        ''
                        ], 
                    user_name = '', 
                    user_session_id = '', 
                    view = '', 
                    viewport_height = -1, 
                    viewport_width = -1, 
                    warm_start_time_ms = -1, ),
                cursor = instana_client.models.cursor.cursor(),
                impacted_beacon_info = instana_client.models.impacted_beacon_info.ImpactedBeaconInfo(
                    country = '', 
                    label = '', 
                    subdivision = '', 
                    user_email = '', 
                    user_name = '', )
            )
        else:
            return MobileAppBeaconsItem(
                beacon = instana_client.models.mobile_app_monitoring_beacon.MobileAppMonitoringBeacon(
                    accuracy_radius = -1, 
                    agent_version = '', 
                    app_build = '', 
                    app_version = '', 
                    app_version_number = -1, 
                    available_mb = -1, 
                    backend_trace_id = '', 
                    batch_size = 1, 
                    beacon_id = '', 
                    bundle_identifier = '', 
                    bytes_ingested = 56, 
                    carrier = '', 
                    city = '', 
                    clock_skew = 0, 
                    cold_start_time_ms = -1, 
                    connection_type = '', 
                    continent = '', 
                    continent_code = '', 
                    country = '', 
                    country_code = '', 
                    current_app_state = '', 
                    custom_event_name = '', 
                    custom_metric = 1.337, 
                    decoded_body_size = -1, 
                    device_hardware = '', 
                    device_manufacturer = '', 
                    device_model = '', 
                    drop_view = '', 
                    duration = 0, 
                    effective_connection_type = '', 
                    encoded_body_size = -1, 
                    environment = '', 
                    error_count = 0, 
                    error_id = '', 
                    error_message = '', 
                    error_type = '', 
                    google_play_services_missing = True, 
                    hot_start_time_ms = -1, 
                    http_call_headers = {
                        'key' : ''
                        }, 
                    http_call_method = '', 
                    http_call_origin = '', 
                    http_call_path = '', 
                    http_call_status = -1, 
                    http_call_url = '', 
                    ingestion_time = 1, 
                    internal_meta = {
                        'key' : ''
                        }, 
                    label = '', 
                    latitude = 1.337, 
                    longitude = 1.337, 
                    max_mb = -1, 
                    meta = {
                        'key' : ''
                        }, 
                    mobile_app_id = '', 
                    mobile_app_label = '', 
                    os_name = '', 
                    os_version = '', 
                    parent_beacon_id = '', 
                    parsed_stack_trace = '', 
                    performance_subtype = '', 
                    platform = '', 
                    rate_limit_beacon_type = '', 
                    rate_limit_count = 0, 
                    rate_limit_custom_metric_val = [
                        1.337
                        ], 
                    rate_limit_time_max = 0, 
                    rate_limit_time_min = 0, 
                    region = '', 
                    rooted = True, 
                    session_id = '', 
                    stack_trace = '', 
                    stack_trace_key_checksum = '', 
                    stack_trace_key_information = '', 
                    stack_trace_line = [
                        instana_client.models.stack_trace_line.StackTraceLine(
                            column = -1, 
                            file = '', 
                            line = -1, 
                            name = '', 
                            translation_explanation = '', 
                            translation_status = -1, )
                        ], 
                    stack_trace_parsing_status = -1, 
                    subdivision = '', 
                    subdivision_code = '', 
                    tenant = '', 
                    timestamp = 1, 
                    transfer_size = -1, 
                    type = '', 
                    unit = '', 
                    use_features = [
                        ''
                        ], 
                    used_mb = -1, 
                    user_email = '', 
                    user_id = '', 
                    user_ip = '', 
                    user_languages = [
                        ''
                        ], 
                    user_name = '', 
                    user_session_id = '', 
                    view = '', 
                    viewport_height = -1, 
                    viewport_width = -1, 
                    warm_start_time_ms = -1, ),
                cursor = instana_client.models.cursor.cursor(),
        )
        """

    def testMobileAppBeaconsItem(self):
        """Test MobileAppBeaconsItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
